/*

 irc-extra.c : irssi

    Copyright (C) 1999 Timo Sirainen

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "irssi.h"

void irc_extra_init(void)
{
    dcc_init();
    dcc_chat_init();
    dcc_files_init();
    extra_commands_init();
    flood_init();
    ignore_init();
    log_init();
    notifylist_init();
    irssi_perl_init();
    plugins_init();
    plugins_setup_init();
    plugin_commands_init();
}

void irc_extra_deinit(void)
{
    dcc_deinit();
    dcc_chat_deinit();
    dcc_files_deinit();
    extra_commands_deinit();
    flood_deinit();
    ignore_deinit();
    log_deinit();
    notifylist_deinit();
    irssi_perl_deinit();
    plugins_deinit();
    plugins_setup_deinit();
    plugin_commands_deinit();
}
